==> schlix-cms-v2.1.8-7.zip: schlix/system/blocks/featured/config.template.php <==
<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
?>
<?php 
  global $SystemDB;
  
  $app_list = get_list_of_all_apps();
  $valid_app_list = array();
  
  foreach ($app_list as $classname)
  {
	 $the_app = '\\App\\'.$classname;
	  $obj = new $the_app;
	  if (method_exists($obj,'getItemTableName'))
	  {
		  $tablename = $obj->getItemTableName();
		  if ($tablename)
		  {
			  $column_exists = $SystemDB->tableColumnExists($tablename,'featured');
			  if ($SystemDB->tableColumnExists($tablename,'featured')) $valid_app_list[] = array('label'=>$classname,'value'=>$classname);
		  }
	  }
  }
?>


<p><?= ___('This block displays a list of featured articles in descending order, sorted by the date created. You can have multiple block assigned to different app. Simply copy and paste this block from the Blocks Admin.') ?></p>
<schlix-config:textbox config-key='str_block_title' label='<?= ___('Header Text') ?>' class="form-control" />
<schlix-config:integerbox config-key='int_max_entries' min="0" max="100" label='<?= ___('Maximum number of post to be displayed (descending order)') ?>' class="form-control" />

<schlix-config:radiogroup config-key="str_app" label="<?= ('Application') ?>">
    <?php foreach ($valid_app_list as $choice): ?>
        <schlix-config:option value="<?= ___h($choice['value']) ?>"><?= ___h($choice['label']) ?></schlix-config:option>
    <?php endforeach ?>
</schlix-config:radiogroup>  

        <schlix-config:textbox config-key="int_cache_result_seconds" label="<?= ___("Cache result for (in seconds)") ?>" class="form-control" config-default-value="120" />
        <p class="small"><?= ___('Caching the result set will help with the performance of your website') ?></p>

==> schlix-cms-v2.2.7-1.zip: schlix/system/blocks/featured/config.template.php <==
<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
?>
<?php 
  global $SystemDB;
  
  $app_list = get_list_of_all_apps();
  $valid_app_list = array();
  
  foreach ($app_list as $classname)
  {
	 $the_app = '\\App\\'.$classname;
	  $obj = new $the_app;
	  if (method_exists($obj,'getItemTableName'))
	  {
		  $tablename = $obj->getItemTableName();
		  if ($tablename)
		  {
			  $column_exists = $SystemDB->tableColumnExists($tablename,'featured');
			  if ($SystemDB->tableColumnExists($tablename,'featured')) $valid_app_list[] = array('label'=>$classname,'value'=>$classname);
		  }
	  }
  }
?>


<p><?= ___('This block displays a list of featured articles in descending order, sorted by the date created. You can have multiple block assigned to different app. Simply copy and paste this block from the Blocks Admin.') ?></p>
<schlix-config:textbox config-key="str_block_title" label="<?= ___('Header Text') ?>"   />
<schlix-config:integerbox config-key="int_max_entries" min="0" max="100" label="<?= ___('Maximum number of post to be displayed (descending order)') ?>"   />

<schlix-config:radiogroup config-key="str_app" label="<?= ('Application') ?>">
    <?php foreach ($valid_app_list as $choice): ?>
        <schlix-config:option value="<?= ___h($choice['value']) ?>"><?= ___h($choice['label']) ?></schlix-config:option>
    <?php endforeach ?>
</schlix-config:radiogroup>  

        <schlix-config:textbox config-key="int_cache_result_seconds" label="<?= ___("Cache result for (in seconds)") ?>"   config-default-value="120" />
        <p class="small"><?= ___('Caching the result set will help with the performance of your website') ?></p>
